OcrResultModel class

Constructors

OcrResultModel({required bool? isSuccess, required String? errorMessage, required String? imagePath, required String? faceImagePath, required Ktp? ktp})
OcrResultModel.fromJson(String source)
factory
OcrResultModel.fromMap(Map<String, dynamic> json)
factory

Properties

errorMessage → String?
final
faceImagePath ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imagePath → String?
final
isSuccess → bool?
final
ktp → Ktp?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setFaceImagePath(String? path) → void
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited